.. _all-salt.returners:

================
returner modules
================

.. currentmodule:: salt.returners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    appoptics_return
    carbon_return
    cassandra_cql_return
    cassandra_return
    couchbase_return
    couchdb_return
    django_return
    elasticsearch_return
    etcd_return
    highstate_return
    influxdb_return
    kafka_return
    librato_return
    local
    local_cache
    mattermost_returner
    memcache_return
    mongo_future_return
    mongo_return
    multi_returner
    mysql
    nagios_nrdp_return
    odbc
    pgjsonb
    postgres
    postgres_local_cache
    pushover_returner
    rawfile_json
    redis_return
    sentry_return
    slack_returner
    slack_webhook_return
    sms_return
    smtp_return
    splunk
    sqlite3_return
    syslog_return
    telegram_return
    xmpp_return
    zabbix_return
